Les utilitaires (utils/) — Zds Member 1.0 documentation

# Les utilitaires (`utils/`)

Module situé dans `zds/utils/`. Il regroupe certaines fonctions et objets utiles à tout les autres modules.

Fichiers documentés :

- Les utilitaires (`utils/`)
  - Modèles (`models.py`)
  - Articles (`articles.py`)
  - Forums (`forums.py`)
  - Messages privés (`mps.py`)
  - Tutoriels (`tutorials.py`)
  - Les processeurs de contexte (`context_processor.py`)
  - Autres (`misc.py`)

## Modèles (`models.py`)

## Articles (`articles.py`)

## Forums (`forums.py`)

## Messages privés (`mps.py`)

## Tutoriels (`tutorials.py`)

## Les processeurs de contexte (`context_processor.py`)

La doc de Django explique le principe des context_processors comme suit :

Un processeur de contexte possède une interface très simple : ce n’est qu’une fonction Python acceptant un paramètre, un objet HttpRequest, et renvoyant un dictionnaire qui est ensuite ajouté au contexte de gabarit. Chaque processeur de contexte doit renvoyer un dictionnaire.
Les processeurs de contexte personnalisés peuvent se trouver n’importe où dans le code. Tout ce que Django demande, c’est que le réglage `TEMPLATE_CONTEXT_PROCESSORS` contienne le chemin vers le processeur personnalisé.

(pour plus de détails, voir la documenation de Django à ce sujet)

## Autres (`misc.py`)